@@ -187,7 +187,9 @@ class UpdateList():
     PHASED_UPDATES_KEY = "Phased-Update-Percentage"
 
     # the file that contains the uniq machine id
-    UNIQ_MACHINE_ID_FILE = "/var/lib/dbus/machine-id"
+    UNIQ_MACHINE_ID_FILE = "/etc/machine-id"
+    # use the dbus one as a fallback
+    UNIQ_MACHINE_ID_FILE_FALLBACK = "/var/lib/dbus/machine-id"
 
     APP_INSTALL_PATTERN = "/usr/share/app-install/desktop/%s:*.desktop"
 
@@ -207,8 +209,12 @@ class UpdateList():
         self.random = random.Random()
         self.ignored_phased_updates = []
         # a stable machine uniq id
-        with open(self.UNIQ_MACHINE_ID_FILE) as f:
-            self.machine_uniq_id = f.read()
+        try:
+            with open(self.UNIQ_MACHINE_ID_FILE) as f:
+                self.machine_uniq_id = f.read()
+        except FileNotFoundError:
+            with open(self.UNIQ_MACHINE_ID_FILE_FALLBACK) as f:
+                self.machine_uniq_id = f.read()
 
         if 'XDG_DATA_DIRS' in os.environ and os.environ['XDG_DATA_DIRS']:
             data_dirs = os.environ['XDG_DATA_DIRS']
