@@ -922,7 +922,7 @@ class UpdatesAvailable(InternalDialog):
             try:
                 if keep_packages:
                     item.pkg.mark_keep()
-                elif not item.pkg.name in self.list.held_back:
+                elif item.pkg.name not in self.list.held_back:
                     item.pkg.mark_install()
             except SystemError:
                 pass
